def generation_aws(terraform_ver, provider_ver, region):
    """_summary_
    Program to generate .tf for aws provider.
    Args:
        terraform_ver (_type_): _description_
        provider_ver (_type_): _description_
        region (_type_): _description_
    """

    template = """terraform {{
    required_version = "= {0}"
    required_providers {{
        aws = {{
            source  = "hashicorp/aws"
            version = "~> {1}"
        }}
    }}
}}
# Configure the AWS Provider
provider "aws" {{
    region = "{2}"
}}""".format(
        terraform_ver, provider_ver, region
    )
    with open("main.tf", "w") as f:
        f.write(template)


def generation_datadog(terraform_ver, provider_ver):
    """_summary_
    Program to generate .tf for datadog provider.
    Args:
        terraform_ver (_type_): _description_
        provider_ver (_type_): _description_
    """
    template = """terraform {{
    required_version = "= {0}"
    required_providers {{
        datadog = {{
            source  = "DataDog/datadog"
            version = "{1}"
        }}
    }}
}}
# Import from TF_VAR_xxx environment variables
variable "datadog_api_key" {{}}
variable "datadog_app_key" {{}}

provider "datadog" {{
    api_key = var.datadog_api_key
    app_key = var.datadog_app_key
}}""".format(
        terraform_ver, provider_ver
    )
    with open("main.tf", "w") as f:
        f.write(template)




import logging
import subprocess

from p_terraformer.cmd.terraform_generator import generation_aws
from p_terraformer.utils.helpers import file_handling , terraform_init
from p_terraformer.utils.helpers import generate_filename
from p_terraformer.utils.helpers import file_handling

def aws_cmd(args):
    if not args.no_tf:
        generation_aws(args.terraform_version, args.aws_provider_version, args.aws_region)
    aws_resources_output(args)

def aws_resources_output(args):
    """_summary_
    Code to run terraformer to generate aws resource

    Args:
        filter (str):       aws filter
        resource (str):     aws resource name
    """
    terraform_init()
    try:
        subprocess.run(
            [
                "terraformer",
                "import",
                "aws",
                "--resources={}".format(args.resource),
                "--filter={}".format(args.filter),
                "--regions={}".format(args.aws_region),
                "--profile={}".format(args.aws_profile),
            ], check=True
        )
        dt_now=generate_filename()
        file_handling(dt_now)
    except:
        logging.warning("Execution failed.")
        return


import logging
import subprocess
from p_terraformer.utils.helpers import generate_filename
from p_terraformer.utils.helpers import file_handling , terraform_init
from p_terraformer.cmd.terraform_generator import generation_datadog
from p_terraformer.config.cli_conf import profile_check , aws_secret_get

def datadog_cmd(args):
    # Whether to generate .tf files
    if not args.no_tf:
        generation_datadog(args.terraform_version, args.datadog_provider_version)
    datadog_resources_output(args)

def datadog_resources_output(args):
    """_summary_
    This program generates terraform code for datadog using terraformer
    Args:
        args (array): argument
    """
    if args.subcommand == "default_secret":
        api_key = args.api_key
        app_key = args.app_key
    else:
        data=profile_check()
        if data!=None:
            result = [d for d in data["profile"] if d['name'] == args.profile]
        else:
            result=None
        if not result:
            logging.info("""
            The profile does not exist.
            sample Command: > p_terraformer profile
                        """)
            return
        else:
            api_key = aws_secret_get(result[0]["api_key"], "api_key", args.region)
            app_key = aws_secret_get(result[0]["app_key"], "app_key", args.region)
    try:
        terraform_init()
        subprocess.run(
            [
                "terraformer",
                "import",
                "{}".format(args.provider),
                "--resources={}".format(args.resource),
                "--api-key={}".format(api_key),
                "--app-key={}".format(app_key),
                "--filter={}={}".format(args.resource, args.resource_id),
            ],
            check=True,
        )
        dt_now = generate_filename()
        file_handling(dt_now)
    except:
        logging.warning("Execution failed.")



import logging
import yaml
import os

from p_terraformer.config.cli_conf import profile_check

def add_datadog_profile():
    """_summary_
    datadog Function to record information to retrieve the access key and secret key.
    """

    data=profile_check()
    profile_name=input("Please enter a profile name >")
    api_key=input("secret manager api_key >")
    app_key=input("secret manager app_key >")
    if profile_name == "" or api_key == "" or app_key == "":
        return "profile_name or api_key or app_key None"
    p_terraformer_config_folder = os.getenv("HOME")+"/.p_terraformer"
    p_terraformer_config_path=p_terraformer_config_folder+"/config.yaml"
    if data["profile"] == []:
        result = None
    else:
        result = [d for d in data["profile"] if d["name"] == profile_name]
    if not result:
        new_data = {
            "name": profile_name,
            "api_key": api_key,
            "app_key": app_key
        }
        data["profile"].append(new_data)
        with open(p_terraformer_config_path, "w") as f:
            yaml.safe_dump(data, f, sort_keys=False)
    else:
        for i in range(len(data)):
            if data["profile"][i]["name"]==profile_name:
                data["profile"][i]["api_key"]=api_key
                data["profile"][i]["app_key"]=app_key
        with open(p_terraformer_config_path, 'w') as f:
            yaml.safe_dump(data, f, sort_keys=False)



"""
This module provides a wrapper for the Terraformer,
allowing users to programmatically interact with Terraformer.
"""

import logging

from p_terraformer.cmd.args import parse_args
from p_terraformer.cmd.aws_generator import aws_cmd
from p_terraformer.cmd.datadog_generator import datadog_cmd
from p_terraformer.cmd.p_terraformer_config_generator import add_datadog_profile

def main():
    logging.basicConfig(level=logging.INFO)
    args,parser,datadog_parser=parse_args()
    if args.provider == None:
        parser.print_help()
    elif args.provider == "datadog":
        if args.subcommand == None:
            logging.info("not Command secret or type")
            logging.info("""
                        sample Command
                        ex) p_terraformer datadog aws_secret or default_secret
                        """)
            datadog_parser.print_help()
        else:
            datadog_cmd(args)
    elif args.provider == "aws":
        aws_cmd(args)
    elif args.provider == "profile":
        add_datadog_profile()
    else:
        parser.print_help()


if __name__ == "__main__":
    main()


import argparse
import os

def parse_args():
    parser = argparse.ArgumentParser(description="p_terraformer CLI")
    subparsers = parser.add_subparsers(
        dest="provider", help="p_terraformer instructions"
    )

    # DATADOG

    # aws secret manager
    datadog_parser = subparsers.add_parser(
        "datadog", help="Datadog terraform Generation"
    )
    secret_parser = datadog_parser.add_subparsers(dest="subcommand")

    aws_secret_parser = secret_parser.add_parser(
        "aws_secret", help="datadog secret type aws secret type"
    )
    aws_secret_parser.add_argument(
        "-p", "--profile",
        type=str,
        required=True,
        help="aws secret manager profile",
    )
    aws_secret_parser.add_argument(
        "--region",
        type=str,
        default="ap-northeast-1",
        help="(--type aws): default aws region ap-northeast-1 :ex) secret manager region ap-northeast-1 >> input ap-northeast-1",
    )
    aws_secret_parser.add_argument(
        "--resource",
        type=str,
        required=True,
        help="default datadog resource dashboard   :ex) datadog resource is monitor >> input monitor",
    )
    aws_secret_parser.add_argument(
        "--resource_id",
        type=str,
        required=True,
        help="Use only to create a .tf for execution.",
    )
    aws_secret_parser.add_argument('--no-tf', action='store_true',
                    help='Do not generate .tf files')
    aws_secret_parser.add_argument(
        "--terraform_version",
        type=str,
        default="0.13.6",
        help="Use only to create a .tf for execution. default terraform version 0.13.6 ex) terraform version 0.14.11 >> input 0.14.11",
    )
    aws_secret_parser.add_argument(
        "--datadog_provider_version",
        type=str,
        default="3.12.0",
        help="Use only to create a .tf for execution. default terraform datadog provider version 3.12.0 ex) datadog provider version 3.12.0 >> input 3.12.0",
    )

    # default secret
    default_secret_parser = secret_parser.add_parser(
        "default_secret", help="datadog secret type default"
    )
    default_secret_parser.add_argument(
        "--api_key",
        type=str,
        required=True,
        help="default app_key :ex) --type default >>{datadog app_key}",
    )
    default_secret_parser.add_argument(
        "--app_key",
        type=str,
        required=True,
        help="default api_key :ex) --type default >>{datadog api_key}",
    )

    default_secret_parser.add_argument(
        "--resource",
        type=str,
        required=True,
        help="default datadog resource dashboard   :ex) datadog resource is monitor >> input monitor",
    )
    default_secret_parser.add_argument(
        "--resource_id",
        type=str,
        required=True,
        help="Use only to create a .tf for execution.",
    )
    default_secret_parser.add_argument('--no-tf', action='store_true',
                    help='Do not generate .tf files')
    default_secret_parser.add_argument(
        "--terraform_version",
        type=str,
        default="0.13.6",
        help="Use only to create a .tf for execution. default terraform version 0.13.6 ex) terraform version 0.14.11 >> input 0.14.11",
    )
    default_secret_parser.add_argument(
        "--datadog_provider_version",
        type=str,
        default="3.12.0",
        help="Use only to create a .tf for execution. default terraform datadog provider version 3.12.0 ex) datadog provider version 3.12.0 >> input 3.12.0",
    )

    # AWS
    aws_parser = subparsers.add_parser("aws", help="AWS terraform Generation")
    aws_parser.add_argument(
        "--aws_profile",
        type=str,
        default="default",
        help="default aws profile default"
    )
    aws_parser.add_argument(
        "--resource",
        type=str,
        required=True,
        help="default aws resource vpc :ex) datadog resource is vpc >> input vpc",
    )
    aws_parser.add_argument(
        "--filter",
        type=str,
        required=True,
        help="for vpc id vpc---xxxxxxxxxx, enter vpc=vpc-xxxxxxxxxxx",
    )
    aws_parser.add_argument('--no-tf', action='store_true',
                    help='Do not generate .tf files')
    aws_parser.add_argument(
        "--terraform_version",
        type=str,
        default="0.13.6",
        help="Use only to create a .tf for execution. default terraform version 0.13.6 ex) terraform version 0.14.11 >> input 0.14.11",
    )
    aws_parser.add_argument(
        "--aws_provider_version",
        type=str,
        default="3.12.0",
        help="Use only to create a .tf for execution. default terraform aws provider version 4.0 ex) datadog provider version 4.0 >> input 4.0",
    )
    aws_parser.add_argument(
        "--aws_region",
        type=str,
        default="ap-northeast-1",
        help="Use only to create a .tf for execution. default aws region ap-northeast-1 ex) aws region ap-northeast-1 >> input ap-northeast-1",
    )

    #profile
    profile_parser = subparsers.add_parser("profile", help="Settings to use with p_terraformer")
    profile_parser.add_argument(
        "profile_list",
        action='store_true',
        help="Display profile list"
    )


    args = parser.parse_args()
    return args,parser,datadog_parser


import ast
import boto3
from botocore.exceptions import ClientError
import os
import yaml

def profile_check():
    p_terraformer_config_folder = os.getenv("HOME")+"/.p_terraformer"
    p_terraformer_config_path=p_terraformer_config_folder+"/config.yaml"
    if not os.path.exists(p_terraformer_config_path):
        os.makedirs(p_terraformer_config_folder, exist_ok=True)
        init_yml = {'profile': []}
        with open(p_terraformer_config_path, 'w') as file:
            yaml.dump(init_yml, file, sort_keys=False)
    with open(p_terraformer_config_path, "r") as f:
        data = yaml.safe_load(f)
    return data

def aws_secret_get(secret_name, secret_value, region_name):
    """_summary_
    Retrieve data from aws secret manager
    Args:
        secret_name (str): secret manager secret name ex) hogehoge/hogehoge
        secret_value(str): secret manager secret key ex) api-key
        region_name (str): secret manager region

    """
    session = boto3.session.Session()
    if os.environ.get("TESTING_FLAG") == "True":
        client = session.client(service_name="secretsmanager", region_name=region_name, endpoint_url="http://localhost:4566")
    else:
        client = session.client(service_name="secretsmanager", region_name=region_name)
    try:
        get_secret_value_response = client.get_secret_value(
            SecretId=secret_name)
    except ClientError as e:
        raise e
    secret = get_secret_value_response["SecretString"]
    dic = ast.literal_eval(secret)
    return dic[str(secret_value)]



from setuptools import setup, find_packages

URL = 'https://github.com/S-mishina/p_terraformer'
AUTHOR = 'S-mishina'

with open('requirements.txt') as f:
    requirements = f.read().splitlines()

setup(
    author=AUTHOR,
    url=URL,
    name='p_terraformer',
    version='0.2',
    packages=find_packages(),
    install_requires=requirements,
    include_package_data=True,
    entry_points={
        'console_scripts': [
            'p_terraformer = p_terraformer.cli:main'
        ]
}
)



from pathlib import Path
import datetime
import subprocess
import logging

def generate_filename():
    """_summary_
    A function to get the current time
    """
    dt_now = datetime.datetime.now()
    dt_now = dt_now.strftime("%Y-%m-%d-%H-%M")
    return dt_now

def file_handling(dt_now):
    """_summary_
    Convert generated folder to date folder
    Args:
        dt_now (str):
    """
    generated_dir = Path("generated")
    generated_dir.rename(dt_now)

def terraform_init():
    """_summary_
    Execute terraform init
    """
    try:
        subprocess.run(["terraform","init"])
    except:
        logging.warning("terraform init did not work!")
